Utilities
=========

.. toctree::
   :maxdepth: 1
   :caption: Utility modules

   utils/exceptions
   utils/format_trials
   utils/format_terminal
   utils/singleton
   utils/points

.. automodule:: orion.core.utils
   :members:
